package quest

import (
	"math/big"
	"validator/util"

	"github.com/ethereum/go-ethereum/common"
	"github.com/ethereum/go-ethereum/crypto"
)

type ProofModel struct {
	TaskType               int
	TaskId                 string
	TaskFinishTimestamp    int
	TaskWorkload           uint64
	TaskReqHash            string
	TaskRespHash           string
	TaskManagerSignature   string
	TaskContainerSignature string
	TaskMinerSignature     string
	TaskProfitAccount      string
	TaskWorkerAccount      string
}

func (p *ProofModel) GenerateHashPayload() []byte {
	return crypto.Keccak256(util.CombineBytes(
		[]byte(p.TaskId),
		common.Hex2Bytes(p.TaskReqHash),
		common.Hex2Bytes(p.TaskRespHash),
	))
}

func (p *ProofModel) GenerateNMHashPayload() []byte {
	return crypto.Keccak256(util.CombineBytes(
		[]byte(p.TaskId),
		common.Hex2Bytes(p.TaskReqHash),
		common.Hex2Bytes(p.TaskRespHash),
		common.HexToAddress(p.TaskProfitAccount).Bytes(),
		common.HexToAddress(p.TaskWorkerAccount).Bytes(),
		common.Hex2Bytes(p.TaskContainerSignature),
		common.Hex2Bytes(p.TaskMinerSignature),
		big.NewInt(int64(p.TaskWorkload)).Bytes(),
		big.NewInt(int64(p.TaskFinishTimestamp)).Bytes(),
	))
}
