package tree

import (
	"bytes"
	"encoding/hex"

	"github.com/ethereum/go-ethereum/common"
)

type Proofs []common.Hash

func (x Proofs) Len() int           { return len(x) }
func (x Proofs) Less(i, j int) bool { return bytes.Compare(x[i][:], x[j][:]) == -1 }
func (x Proofs) Swap(i, j int)      { x[i], x[j] = x[j], x[i] }

func (x Proofs) Distinct() Proofs {
	r := make(Proofs, 0, len(x))
	for idx, el := range x {
		if idx == 0 || !bytes.Equal(x[idx-1][:], el[:]) {
			r = append(r, el)
		}
	}
	return r
}

func (x Proofs) ToHexArray() []string {
	r := make([]string, 0, len(x))
	for _, el := range x {
		r = append(r, hex.EncodeToString(el[:]))
	}
	return r
}
